# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: szconfig.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eszconfig.proto\x12\x08szconfig\"D\n\x14\x41\x64\x64\x44\x61taSourceRequest\x12\x14\n\x0c\x63onfigHandle\x18\x01 \x01(\x03\x12\x16\n\x0e\x64\x61taSourceCode\x18\x02 \x01(\t\"\'\n\x15\x41\x64\x64\x44\x61taSourceResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"*\n\x12\x43loseConfigRequest\x12\x14\n\x0c\x63onfigHandle\x18\x01 \x01(\x03\"\x15\n\x13\x43loseConfigResponse\"\x15\n\x13\x43reateConfigRequest\"&\n\x14\x43reateConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"G\n\x17\x44\x65leteDataSourceRequest\x12\x14\n\x0c\x63onfigHandle\x18\x01 \x01(\x03\x12\x16\n\x0e\x64\x61taSourceCode\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteDataSourceResponse\"+\n\x13\x45xportConfigRequest\x12\x14\n\x0c\x63onfigHandle\x18\x01 \x01(\x03\"&\n\x14\x45xportConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"-\n\x15GetDataSourcesRequest\x12\x14\n\x0c\x63onfigHandle\x18\x01 \x01(\x03\"(\n\x16GetDataSourcesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"/\n\x13ImportConfigRequest\x12\x18\n\x10\x63onfigDefinition\x18\x01 \x01(\t\"&\n\x14ImportConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\x32\xd3\x04\n\x08SzConfig\x12R\n\rAddDataSource\x12\x1e.szconfig.AddDataSourceRequest\x1a\x1f.szconfig.AddDataSourceResponse\"\x00\x12L\n\x0b\x43loseConfig\x12\x1c.szconfig.CloseConfigRequest\x1a\x1d.szconfig.CloseConfigResponse\"\x00\x12O\n\x0c\x43reateConfig\x12\x1d.szconfig.CreateConfigRequest\x1a\x1e.szconfig.CreateConfigResponse\"\x00\x12[\n\x10\x44\x65leteDataSource\x12!.szconfig.DeleteDataSourceRequest\x1a\".szconfig.DeleteDataSourceResponse\"\x00\x12O\n\x0c\x45xportConfig\x12\x1d.szconfig.ExportConfigRequest\x1a\x1e.szconfig.ExportConfigResponse\"\x00\x12U\n\x0eGetDataSources\x12\x1f.szconfig.GetDataSourcesRequest\x1a .szconfig.GetDataSourcesResponse\"\x00\x12O\n\x0cImportConfig\x12\x1d.szconfig.ImportConfigRequest\x1a\x1e.szconfig.ImportConfigResponse\"\x00\x42g\n#com.senzing.sz.engine.grpc.SzConfigB\rSzConfigProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szconfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szconfig_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.senzing.sz.engine.grpc.SzConfigB\rSzConfigProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szconfig'
  _globals['_ADDDATASOURCEREQUEST']._serialized_start=28
  _globals['_ADDDATASOURCEREQUEST']._serialized_end=96
  _globals['_ADDDATASOURCERESPONSE']._serialized_start=98
  _globals['_ADDDATASOURCERESPONSE']._serialized_end=137
  _globals['_CLOSECONFIGREQUEST']._serialized_start=139
  _globals['_CLOSECONFIGREQUEST']._serialized_end=181
  _globals['_CLOSECONFIGRESPONSE']._serialized_start=183
  _globals['_CLOSECONFIGRESPONSE']._serialized_end=204
  _globals['_CREATECONFIGREQUEST']._serialized_start=206
  _globals['_CREATECONFIGREQUEST']._serialized_end=227
  _globals['_CREATECONFIGRESPONSE']._serialized_start=229
  _globals['_CREATECONFIGRESPONSE']._serialized_end=267
  _globals['_DELETEDATASOURCEREQUEST']._serialized_start=269
  _globals['_DELETEDATASOURCEREQUEST']._serialized_end=340
  _globals['_DELETEDATASOURCERESPONSE']._serialized_start=342
  _globals['_DELETEDATASOURCERESPONSE']._serialized_end=368
  _globals['_EXPORTCONFIGREQUEST']._serialized_start=370
  _globals['_EXPORTCONFIGREQUEST']._serialized_end=413
  _globals['_EXPORTCONFIGRESPONSE']._serialized_start=415
  _globals['_EXPORTCONFIGRESPONSE']._serialized_end=453
  _globals['_GETDATASOURCESREQUEST']._serialized_start=455
  _globals['_GETDATASOURCESREQUEST']._serialized_end=500
  _globals['_GETDATASOURCESRESPONSE']._serialized_start=502
  _globals['_GETDATASOURCESRESPONSE']._serialized_end=542
  _globals['_IMPORTCONFIGREQUEST']._serialized_start=544
  _globals['_IMPORTCONFIGREQUEST']._serialized_end=591
  _globals['_IMPORTCONFIGRESPONSE']._serialized_start=593
  _globals['_IMPORTCONFIGRESPONSE']._serialized_end=631
  _globals['_SZCONFIG']._serialized_start=634
  _globals['_SZCONFIG']._serialized_end=1229
# @@protoc_insertion_point(module_scope)



#! /usr/bin/env python3

"""
TODO: szengine_grpc.py
"""

# pylint: disable=E1101,C0302

import json
from types import TracebackType
from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, Union

import grpc
from senzing_abstract import SzEngineAbstract, SzEngineFlags

from .pb2_grpc import szengine_pb2, szengine_pb2_grpc
from .szhelpers import as_str, new_exception

# Metadata

__all__ = ["SzEngine"]
__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2023-11-27"
__updated__ = "2024-07-30"

SENZING_PRODUCT_ID = (
    "5053"  # See https://github.com/senzing-garage/knowledge-base/blob/main/lists/senzing-component-ids.md
)

# -----------------------------------------------------------------------------
# SzEngine class
# -----------------------------------------------------------------------------


class SzEngine(SzEngineAbstract):
    """
    Sz engine module access library over gRPC.
    """

    # -------------------------------------------------------------------------
    # Python dunder/magic methods
    # -------------------------------------------------------------------------

    def __init__(
        self,
        grpc_channel: grpc.Channel,
    ) -> None:
        """
        Constructor

        For return value of -> None, see https://peps.python.org/pep-0484/#the-meaning-of-annotations
        """

        self.channel = grpc_channel
        self.stub = szengine_pb2_grpc.SzEngineStub(self.channel)
        self.noop = ""

    def __enter__(
        self,
    ) -> Any:  # TODO: Replace "Any" with "Self" once python 3.11 is lowest supported python version.
        """Context Manager method."""
        return self

    def __exit__(
        self,
        exc_type: Union[Type[BaseException], None],
        exc_val: Union[BaseException, None],
        exc_tb: Union[TracebackType, None],
    ) -> None:
        """Context Manager method."""

    # -------------------------------------------------------------------------
    # SzEngine methods
    # -------------------------------------------------------------------------

    def add_record(
        self,
        data_source_code: str,
        record_id: str,
        record_definition: str,
        flags: int = 0,
    ) -> str:
        try:
            request = szengine_pb2.AddRecordRequest(  # type: ignore[unused-ignore]
                dataSourceCode=as_str(data_source_code),
                recordId=as_str(record_id),
                recordDefinition=as_str(record_definition),
                flags=flags,
            )
            response = self.stub.AddRecord(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def close_export(self, export_handle: int) -> None:
        try:
            request = szengine_pb2.CloseExportRequest(  # type: ignore[unused-ignore]
                exportHandle=export_handle,
            )
            self.stub.CloseExport(request)
        except Exception as err:
            raise new_exception(err) from err

    def count_redo_records(self) -> int:
        try:
            request = szengine_pb2.CountRedoRecordsRequest()  # type: ignore[unused-ignore]
            response = self.stub.CountRedoRecords(request)
            return int(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def delete_record(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = 0,
    ) -> str:
        try:
            request = szengine_pb2.DeleteRecordRequest(  # type: ignore[unused-ignore]
                dataSourceCode=as_str(data_source_code),
                recordId=as_str(record_id),
                flags=flags,
            )
            response = self.stub.DeleteRecord(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def _destroy(self) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""

    def export_csv_entity_report(
        self,
        csv_column_list: str,
        flags: int = SzEngineFlags.SZ_EXPORT_DEFAULT_FLAGS,
    ) -> int:
        try:
            request = szengine_pb2.ExportCsvEntityReportRequest(  # type: ignore[unused-ignore]
                csvColumnList=as_str(csv_column_list),
                flags=flags,
            )
            response = self.stub.ExportCsvEntityReport(request)
            return int(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def export_csv_entity_report_iterator(
        self,
        csv_column_list: str,
        flags: int = SzEngineFlags.SZ_EXPORT_DEFAULT_FLAGS,
    ) -> Iterable[str]:
        """TODO: Add method docstring to export_csv_entity_report_iterator."""
        try:
            request = szengine_pb2.StreamExportCsvEntityReportRequest(  # type: ignore[unused-ignore]
                csvColumnList=as_str(csv_column_list), flags=flags
            )
            for item in self.stub.StreamExportCsvEntityReport(request):
                if item.result:
                    yield item.result
        except Exception as err:
            raise new_exception(err) from err

    def export_json_entity_report(self, flags: int = SzEngineFlags.SZ_EXPORT_DEFAULT_FLAGS) -> int:
        try:
            request = szengine_pb2.ExportJsonEntityReportRequest(  # type: ignore[unused-ignore]
                flags=flags,
            )
            response = self.stub.ExportJsonEntityReport(request)
            return int(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def export_json_entity_report_iterator(
        self,
        flags: int = SzEngineFlags.SZ_EXPORT_DEFAULT_FLAGS,
    ) -> Iterable[str]:
        """TODO: Add method docstring to export_json_entity_report_iterator."""
        try:
            request = szengine_pb2.StreamExportJsonEntityReportRequest(flags=flags)  # type: ignore[unused-ignore]
            for item in self.stub.StreamExportJsonEntityReport(request):
                if item.result:
                    yield item.result
        except Exception as err:
            raise new_exception(err) from err

    def fetch_next(self, export_handle: int) -> str:
        try:
            request = szengine_pb2.FetchNextRequest(  # type: ignore[unused-ignore]
                exportHandle=export_handle,
            )
            response = self.stub.FetchNext(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def find_interesting_entities_by_entity_id(self, entity_id: int, flags: int = 0) -> str:
        try:
            request = szengine_pb2.FindInterestingEntitiesByEntityIdRequest(  # type: ignore[unused-ignore]
                entityId=entity_id,
                flags=flags,
            )
            response = self.stub.FindInterestingEntitiesByEntityId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def find_interesting_entities_by_record_id(self, data_source_code: str, record_id: str, flags: int = 0) -> str:
        try:
            request = szengine_pb2.FindInterestingEntitiesByRecordIdRequest(  # type: ignore[unused-ignore]
                dataSourceCode=as_str(data_source_code),
                recordId=as_str(record_id),
                flags=flags,
            )
            response = self.stub.FindInterestingEntitiesByRecordId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def find_network_by_entity_id(
        self,
        entity_ids: List[int],
        max_degrees: int,
        build_out_degrees: int,
        build_out_max_entities: int,
        flags: int = SzEngineFlags.SZ_FIND_NETWORK_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.FindNetworkByEntityIdRequest(  # type: ignore[unused-ignore]
                entityIds=entity_ids_json(entity_ids),
                maxDegrees=max_degrees,
                buildOutDegrees=build_out_degrees,
                buildOutMaxEntities=build_out_max_entities,
                flags=flags,
            )
            response = self.stub.FindNetworkByEntityId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def find_network_by_record_id(
        self,
        record_keys: List[Tuple[str, str]],
        max_degrees: int,
        build_out_degrees: int,
        build_out_max_entities: int,
        flags: int = SzEngineFlags.SZ_FIND_NETWORK_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.FindNetworkByRecordIdRequest(  # type: ignore[unused-ignore]
                recordKeys=record_keys_json(record_keys),
                maxDegrees=max_degrees,
                buildOutDegrees=build_out_degrees,
                buildOutMaxEntities=build_out_max_entities,
                flags=flags,
            )
            response = self.stub.FindNetworkByRecordId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def find_path_by_entity_id(
        self,
        start_entity_id: int,
        end_entity_id: int,
        max_degrees: int,
        # TODO Should accept both entity and record IDs in V4, test
        avoid_entity_ids: Optional[List[int]] = None,
        required_data_sources: Optional[List[str]] = None,
        flags: int = SzEngineFlags.SZ_FIND_PATH_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.FindPathByEntityIdRequest(  # type: ignore[unused-ignore]
                startEntityId=start_entity_id,
                endEntityId=end_entity_id,
                maxDegrees=max_degrees,
                avoidEntityIds=avoid_entity_ids_json(avoid_entity_ids),
                requiredDataSources=required_data_sources_json(required_data_sources),
                flags=flags,
            )
            response = self.stub.FindPathByEntityId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def find_path_by_record_id(
        self,
        start_data_source_code: str,
        start_record_id: str,
        end_data_source_code: str,
        end_record_id: str,
        max_degrees: int,
        avoid_record_keys: Optional[List[Tuple[str, str]]] = None,
        required_data_sources: Optional[List[str]] = None,
        flags: int = SzEngineFlags.SZ_FIND_PATH_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.FindPathByRecordIdRequest(  # type: ignore[unused-ignore]
                startDataSourceCode=as_str(start_data_source_code),
                startRecordId=as_str(start_record_id),
                endDataSourceCode=as_str(end_data_source_code),
                endRecordId=as_str(end_record_id),
                maxDegrees=max_degrees,
                avoidRecordKeys=avoid_record_keys_json(avoid_record_keys),
                requiredDataSources=required_data_sources_json(required_data_sources),
                flags=flags,
            )
            response = self.stub.FindPathByRecordId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_active_config_id(self) -> int:
        try:
            request = szengine_pb2.GetActiveConfigIdRequest()  # type: ignore[unused-ignore]
            response = self.stub.GetActiveConfigId(request)
            return int(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_entity_by_entity_id(
        self,
        entity_id: int,
        flags: int = SzEngineFlags.SZ_ENTITY_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.GetEntityByEntityIdRequest(  # type: ignore[unused-ignore]
                entityId=entity_id,
                flags=flags,
            )
            response = self.stub.GetEntityByEntityId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_entity_by_record_id(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = SzEngineFlags.SZ_ENTITY_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.GetEntityByRecordIdRequest(  # type: ignore[unused-ignore]
                dataSourceCode=as_str(data_source_code),
                recordId=as_str(record_id),
                flags=flags,
            )
            response = self.stub.GetEntityByRecordId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_record(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = SzEngineFlags.SZ_RECORD_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.GetRecordRequest(  # type: ignore[unused-ignore]
                dataSourceCode=as_str(data_source_code),
                recordId=as_str(record_id),
                flags=flags,
            )
            response = self.stub.GetRecord(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_redo_record(self) -> str:
        try:
            request = szengine_pb2.GetRedoRecordRequest()  # type: ignore[unused-ignore]
            response = self.stub.GetRedoRecord(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_stats(self) -> str:
        try:
            request = szengine_pb2.GetStatsRequest()  # type: ignore[unused-ignore]
            response = self.stub.GetStats(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_virtual_entity_by_record_id(
        self,
        record_keys: List[Tuple[str, str]],
        flags: int = SzEngineFlags.SZ_VIRTUAL_ENTITY_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.GetVirtualEntityByRecordIdRequest(  # type: ignore[unused-ignore]
                recordKeys=record_keys_json(record_keys),
                flags=flags,
            )
            response = self.stub.GetVirtualEntityByRecordId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def how_entity_by_entity_id(
        self,
        entity_id: int,
        flags: int = SzEngineFlags.SZ_HOW_ENTITY_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.HowEntityByEntityIdRequest(  # type: ignore[unused-ignore]
                entityId=entity_id,
                flags=flags,
            )
            response = self.stub.HowEntityByEntityId(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def _initialize(
        self,
        instance_name: str,
        settings: Union[str, Dict[Any, Any]],
        config_id: Optional[int] = None,
        verbose_logging: int = 0,
    ) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""
        _ = instance_name
        _ = settings
        _ = config_id
        _ = verbose_logging

    def preprocess_record(
        self,
        record_definition: str,
        flags: int = SzEngineFlags.SZ_RECORD_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.PreprocessRecordRequest(  # type: ignore[unused-ignore]
                recordDefinition=as_str(record_definition),
                flags=flags,
            )
            response = self.stub.PreprocessRecord(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def prime_engine(self) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""

    def process_redo_record(self, redo_record: str, flags: int = 0) -> str:
        try:
            request = szengine_pb2.ProcessRedoRecordRequest(  # type: ignore[unused-ignore]
                redoRecord=as_str(redo_record),
                flags=flags,
            )
            response = self.stub.ProcessRedoRecord(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def reevaluate_entity(self, entity_id: int, flags: int = 0) -> str:
        try:
            request = szengine_pb2.ReevaluateEntityRequest(  # type: ignore[unused-ignore]
                entityId=entity_id,
                flags=flags,
            )
            response = self.stub.ReevaluateEntity(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def reevaluate_record(self, data_source_code: str, record_id: str, flags: int = 0) -> str:
        try:
            request = szengine_pb2.ReevaluateRecordRequest(  # type: ignore[unused-ignore]
                dataSourceCode=as_str(data_source_code),
                recordId=as_str(record_id),
                flags=flags,
            )
            response = self.stub.ReevaluateRecord(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def _reinitialize(self, config_id: int) -> None:
        try:
            request = szengine_pb2.ReinitializeRequest(configId=config_id)  # type: ignore[unused-ignore]
            self.stub.Reinitialize(request)
        except Exception as err:
            raise new_exception(err) from err

    def search_by_attributes(
        self,
        attributes: str,
        flags: int = SzEngineFlags.SZ_SEARCH_BY_ATTRIBUTES_DEFAULT_FLAGS,
        search_profile: str = "",
    ) -> str:
        try:
            request = szengine_pb2.SearchByAttributesRequest(  # type: ignore[unused-ignore]
                attributes=as_str(attributes),
                searchProfile=as_str(search_profile),
                flags=flags,
            )
            response = self.stub.SearchByAttributes(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def why_entities(
        self,
        entity_id_1: int,
        entity_id_2: int,
        flags: int = SzEngineFlags.SZ_WHY_ENTITIES_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.WhyEntitiesRequest(  # type: ignore[unused-ignore]
                entityId1=entity_id_1,
                entityId2=entity_id_2,
                flags=flags,
            )
            response = self.stub.WhyEntities(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def why_record_in_entity(
        self,
        data_source_code: str,
        record_id: str,
        flags: int = SzEngineFlags.SZ_WHY_RECORDS_DEFAULT_FLAGS,
    ) -> str:
        # TODO: Implement after V3 is published.
        try:
            request = szengine_pb2.WhyRecordInEntityRequest(  # type: ignore[unused-ignore]
                dataSourceCode=as_str(data_source_code),
                recordId=as_str(record_id),
                flags=flags,
            )
            response = self.stub.WhyRecordInEntity(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def why_records(
        self,
        data_source_code_1: str,
        record_id_1: str,
        data_source_code_2: str,
        record_id_2: str,
        flags: int = SzEngineFlags.SZ_WHY_RECORDS_DEFAULT_FLAGS,
    ) -> str:
        try:
            request = szengine_pb2.WhyRecordsRequest(  # type: ignore[unused-ignore]
                dataSourceCode1=as_str(data_source_code_1),
                recordId1=as_str(record_id_1),
                dataSourceCode2=as_str(data_source_code_2),
                recordId2=as_str(record_id_2),
                flags=flags,
            )
            response = self.stub.WhyRecords(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err


# -----------------------------------------------------------------------------
# Helper functions
# -----------------------------------------------------------------------------


def entity_ids_json(entity_ids: List[int]) -> str:
    entity_list = []
    for entity_id in entity_ids:
        entity_list.append({"ENTITY_ID": entity_id})
    return json.dumps({"ENTITIES": entity_list})


def record_keys_json(record_keys: List[Tuple[str, str]]) -> str:
    record_key_list = []
    for record_key in record_keys:
        record_key_list.append({"DATA_SOURCE": record_key[0], "RECORD_ID": record_key[1]})
    return json.dumps({"RECORDS": record_key_list})


def avoid_entity_ids_json(avoid_entity_ids: Optional[List[int]] = None) -> str:
    result = ""
    if avoid_entity_ids:
        avoid_entity_id_list = []
        for avoid_entity_id in avoid_entity_ids:
            avoid_entity_id_list.append({"ENTITY_ID": avoid_entity_id})
        result = json.dumps({"ENTITIES": avoid_entity_id_list})
    return result


def avoid_record_keys_json(avoid_record_keys: Optional[List[Tuple[str, str]]] = None) -> str:
    result = ""
    if avoid_record_keys:
        avoid_record_keys_list = []
        for avoid_record_key in avoid_record_keys:
            avoid_record_keys_list.append(
                {
                    "DATA_SOURCE": avoid_record_key[0],
                    "RECORD_ID": avoid_record_key[1],
                }
            )
        result = json.dumps({"RECORDS": avoid_record_keys_list})
    return result


def required_data_sources_json(
    required_data_sources: Optional[List[str]] = None,
) -> str:
    result = ""
    if required_data_sources:
        required_data_sources_list = []
        for required_data_source in required_data_sources:
            required_data_sources_list.append(required_data_source)
        result = json.dumps({"DATA_SOURCES": required_data_sources_list})
    return result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: szconfigmanager.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15szconfigmanager.proto\x12\x0fszconfigmanager\"C\n\x10\x41\x64\x64\x43onfigRequest\x12\x18\n\x10\x63onfigDefinition\x18\x01 \x01(\t\x12\x15\n\rconfigComment\x18\x02 \x01(\t\"#\n\x11\x41\x64\x64\x43onfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"$\n\x10GetConfigRequest\x12\x10\n\x08\x63onfigId\x18\x01 \x01(\x03\"#\n\x11GetConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x13\n\x11GetConfigsRequest\"$\n\x12GetConfigsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x1b\n\x19GetDefaultConfigIdRequest\",\n\x1aGetDefaultConfigIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"[\n\x1dReplaceDefaultConfigIdRequest\x12\x1e\n\x16\x63urrentDefaultConfigId\x18\x01 \x01(\x03\x12\x1a\n\x12newDefaultConfigId\x18\x02 \x01(\x03\" \n\x1eReplaceDefaultConfigIdResponse\"-\n\x19SetDefaultConfigIdRequest\x12\x10\n\x08\x63onfigId\x18\x01 \x01(\x03\"\x1c\n\x1aSetDefaultConfigIdResponse2\xf5\x04\n\x0fSzConfigManager\x12T\n\tAddConfig\x12!.szconfigmanager.AddConfigRequest\x1a\".szconfigmanager.AddConfigResponse\"\x00\x12T\n\tGetConfig\x12!.szconfigmanager.GetConfigRequest\x1a\".szconfigmanager.GetConfigResponse\"\x00\x12W\n\nGetConfigs\x12\".szconfigmanager.GetConfigsRequest\x1a#.szconfigmanager.GetConfigsResponse\"\x00\x12o\n\x12GetDefaultConfigId\x12*.szconfigmanager.GetDefaultConfigIdRequest\x1a+.szconfigmanager.GetDefaultConfigIdResponse\"\x00\x12{\n\x16ReplaceDefaultConfigId\x12..szconfigmanager.ReplaceDefaultConfigIdRequest\x1a/.szconfigmanager.ReplaceDefaultConfigIdResponse\"\x00\x12o\n\x12SetDefaultConfigId\x12*.szconfigmanager.SetDefaultConfigIdRequest\x1a+.szconfigmanager.SetDefaultConfigIdResponse\"\x00\x42|\n*com.senzing.sz.engine.grpc.SzConfigManagerB\x14SzConfigManagerProtoZ8github.com/senzing-garage/sz-sdk-go-grpc/szconfigmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szconfigmanager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.senzing.sz.engine.grpc.SzConfigManagerB\024SzConfigManagerProtoZ8github.com/senzing-garage/sz-sdk-go-grpc/szconfigmanager'
  _globals['_ADDCONFIGREQUEST']._serialized_start=42
  _globals['_ADDCONFIGREQUEST']._serialized_end=109
  _globals['_ADDCONFIGRESPONSE']._serialized_start=111
  _globals['_ADDCONFIGRESPONSE']._serialized_end=146
  _globals['_GETCONFIGREQUEST']._serialized_start=148
  _globals['_GETCONFIGREQUEST']._serialized_end=184
  _globals['_GETCONFIGRESPONSE']._serialized_start=186
  _globals['_GETCONFIGRESPONSE']._serialized_end=221
  _globals['_GETCONFIGSREQUEST']._serialized_start=223
  _globals['_GETCONFIGSREQUEST']._serialized_end=242
  _globals['_GETCONFIGSRESPONSE']._serialized_start=244
  _globals['_GETCONFIGSRESPONSE']._serialized_end=280
  _globals['_GETDEFAULTCONFIGIDREQUEST']._serialized_start=282
  _globals['_GETDEFAULTCONFIGIDREQUEST']._serialized_end=309
  _globals['_GETDEFAULTCONFIGIDRESPONSE']._serialized_start=311
  _globals['_GETDEFAULTCONFIGIDRESPONSE']._serialized_end=355
  _globals['_REPLACEDEFAULTCONFIGIDREQUEST']._serialized_start=357
  _globals['_REPLACEDEFAULTCONFIGIDREQUEST']._serialized_end=448
  _globals['_REPLACEDEFAULTCONFIGIDRESPONSE']._serialized_start=450
  _globals['_REPLACEDEFAULTCONFIGIDRESPONSE']._serialized_end=482
  _globals['_SETDEFAULTCONFIGIDREQUEST']._serialized_start=484
  _globals['_SETDEFAULTCONFIGIDREQUEST']._serialized_end=529
  _globals['_SETDEFAULTCONFIGIDRESPONSE']._serialized_start=531
  _globals['_SETDEFAULTCONFIGIDRESPONSE']._serialized_end=559
  _globals['_SZCONFIGMANAGER']._serialized_start=562
  _globals['_SZCONFIGMANAGER']._serialized_end=1191
# @@protoc_insertion_point(module_scope)



#! /usr/bin/env python3

"""
TODO: szabstractfactory.py
"""

# pylint: disable=E1101

from types import TracebackType
from typing import Any, Type, TypedDict, Union

import grpc
from senzing_abstract import (
    SzAbstractFactoryAbstract,
    SzConfigAbstract,
    SzConfigManagerAbstract,
    SzDiagnosticAbstract,
    SzEngineAbstract,
    SzProductAbstract,
)

from .szconfig import SzConfig
from .szconfigmanager import SzConfigManager
from .szdiagnostic import SzDiagnostic
from .szengine import SzEngine
from .szproduct import SzProduct

# Metadata

__all__ = ["SzAbstractFactoryAbstract"]
__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2023-11-27"
__updated__ = "2024-10-24"


# -----------------------------------------------------------------------------
# SzAbstractFactoryParameters class
# -----------------------------------------------------------------------------


class SzAbstractFactoryParameters(TypedDict, total=False):
    """
    SzAbstractFactoryParameters is used to create a dictionary that can be unpacked when creating an SzAbstractFactory.
    """

    grpc_channel: grpc.Channel


# -----------------------------------------------------------------------------
# SzAbstractFactory class
# -----------------------------------------------------------------------------


class SzAbstractFactory(SzAbstractFactoryAbstract):
    """
    SzAbstractFactory module is a factory pattern for accessing Senzing over gRPC.
    """

    # -------------------------------------------------------------------------
    # Python dunder/magic methods
    # -------------------------------------------------------------------------

    def __init__(
        self,
        grpc_channel: grpc.Channel,
    ) -> None:
        """
        Constructor

        For return value of -> None, see https://peps.python.org/pep-0484/#the-meaning-of-annotations
        """
        self.channel = grpc_channel

    def __enter__(
        self,
    ) -> Any:  # TODO: Replace "Any" with "Self" once python 3.11 is lowest supported python version.
        """Context Manager method."""
        return self

    def __exit__(
        self,
        exc_type: Union[Type[BaseException], None],
        exc_val: Union[BaseException, None],
        exc_tb: Union[TracebackType, None],
    ) -> None:
        """Context Manager method."""

    # -------------------------------------------------------------------------
    # SzAbstractFactory methods
    # -------------------------------------------------------------------------

    def create_config(self) -> SzConfigAbstract:
        return SzConfig(grpc_channel=self.channel)

    def create_configmanager(self) -> SzConfigManagerAbstract:
        return SzConfigManager(grpc_channel=self.channel)

    def create_diagnostic(self) -> SzDiagnosticAbstract:
        return SzDiagnostic(grpc_channel=self.channel)

    def create_engine(self) -> SzEngineAbstract:
        return SzEngine(grpc_channel=self.channel)

    def create_product(self) -> SzProductAbstract:
        return SzProduct(grpc_channel=self.channel)

    def reinitialize(self, config_id: int) -> None:
        sz_diagonstic = SzDiagnostic(grpc_channel=self.channel)
        sz_diagonstic._reinitialize(config_id=config_id)  # pylint: disable=W0212

        sz_engine = SzEngine(grpc_channel=self.channel)
        sz_engine._reinitialize(config_id=config_id)  # pylint: disable=W0212



#! /usr/bin/env python3

"""
TODO: szproduct_grpc.py
"""

# pylint: disable=E1101

from types import TracebackType
from typing import Any, Dict, Type, Union

import grpc
from senzing_abstract import SzProductAbstract

from .pb2_grpc import szproduct_pb2, szproduct_pb2_grpc
from .szhelpers import new_exception

# Metadata

__all__ = ["SzProduct"]
__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2023-11-27"
__updated__ = "2024-07-30"

SENZING_PRODUCT_ID = (
    "5056"  # See https://github.com/senzing-garage/knowledge-base/blob/main/lists/senzing-component-ids.md
)

# -----------------------------------------------------------------------------
# SzProduct class
# -----------------------------------------------------------------------------


class SzProduct(SzProductAbstract):
    """
    SzProduct module access library over gRPC.
    """

    # -------------------------------------------------------------------------
    # Python dunder/magic methods
    # -------------------------------------------------------------------------

    def __init__(
        self,
        grpc_channel: grpc.Channel,
    ) -> None:
        """
        Constructor

        For return value of -> None, see https://peps.python.org/pep-0484/#the-meaning-of-annotations
        """
        # pylint: disable=W0613

        self.channel = grpc_channel
        self.stub = szproduct_pb2_grpc.SzProductStub(self.channel)

    def __enter__(
        self,
    ) -> Any:  # TODO: Replace "Any" with "Self" once python 3.11 is lowest supported python version.
        """Context Manager method."""
        return self

    def __exit__(
        self,
        exc_type: Union[Type[BaseException], None],
        exc_val: Union[BaseException, None],
        exc_tb: Union[TracebackType, None],
    ) -> None:
        """Context Manager method."""

    # -------------------------------------------------------------------------
    # SzProduct methods
    # -------------------------------------------------------------------------

    def _destroy(self) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""

    def _initialize(
        self,
        instance_name: str,
        settings: Union[str, Dict[Any, Any]],
        verbose_logging: int = 0,
    ) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""
        _ = instance_name
        _ = settings
        _ = verbose_logging

    def get_license(self) -> str:
        try:
            request = szproduct_pb2.GetLicenseRequest()  # type: ignore[unused-ignore]
            response = self.stub.GetLicense(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_version(self) -> str:
        try:
            request = szproduct_pb2.GetVersionRequest()  # type: ignore[unused-ignore]
            response = self.stub.GetVersion(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import szconfig_pb2 as szconfig__pb2

GRPC_GENERATED_VERSION = '1.66.2'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in szconfig_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SzConfigStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddDataSource = channel.unary_unary(
                '/szconfig.SzConfig/AddDataSource',
                request_serializer=szconfig__pb2.AddDataSourceRequest.SerializeToString,
                response_deserializer=szconfig__pb2.AddDataSourceResponse.FromString,
                _registered_method=True)
        self.CloseConfig = channel.unary_unary(
                '/szconfig.SzConfig/CloseConfig',
                request_serializer=szconfig__pb2.CloseConfigRequest.SerializeToString,
                response_deserializer=szconfig__pb2.CloseConfigResponse.FromString,
                _registered_method=True)
        self.CreateConfig = channel.unary_unary(
                '/szconfig.SzConfig/CreateConfig',
                request_serializer=szconfig__pb2.CreateConfigRequest.SerializeToString,
                response_deserializer=szconfig__pb2.CreateConfigResponse.FromString,
                _registered_method=True)
        self.DeleteDataSource = channel.unary_unary(
                '/szconfig.SzConfig/DeleteDataSource',
                request_serializer=szconfig__pb2.DeleteDataSourceRequest.SerializeToString,
                response_deserializer=szconfig__pb2.DeleteDataSourceResponse.FromString,
                _registered_method=True)
        self.ExportConfig = channel.unary_unary(
                '/szconfig.SzConfig/ExportConfig',
                request_serializer=szconfig__pb2.ExportConfigRequest.SerializeToString,
                response_deserializer=szconfig__pb2.ExportConfigResponse.FromString,
                _registered_method=True)
        self.GetDataSources = channel.unary_unary(
                '/szconfig.SzConfig/GetDataSources',
                request_serializer=szconfig__pb2.GetDataSourcesRequest.SerializeToString,
                response_deserializer=szconfig__pb2.GetDataSourcesResponse.FromString,
                _registered_method=True)
        self.ImportConfig = channel.unary_unary(
                '/szconfig.SzConfig/ImportConfig',
                request_serializer=szconfig__pb2.ImportConfigRequest.SerializeToString,
                response_deserializer=szconfig__pb2.ImportConfigResponse.FromString,
                _registered_method=True)


class SzConfigServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataSources(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SzConfigServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDataSource,
                    request_deserializer=szconfig__pb2.AddDataSourceRequest.FromString,
                    response_serializer=szconfig__pb2.AddDataSourceResponse.SerializeToString,
            ),
            'CloseConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseConfig,
                    request_deserializer=szconfig__pb2.CloseConfigRequest.FromString,
                    response_serializer=szconfig__pb2.CloseConfigResponse.SerializeToString,
            ),
            'CreateConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConfig,
                    request_deserializer=szconfig__pb2.CreateConfigRequest.FromString,
                    response_serializer=szconfig__pb2.CreateConfigResponse.SerializeToString,
            ),
            'DeleteDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataSource,
                    request_deserializer=szconfig__pb2.DeleteDataSourceRequest.FromString,
                    response_serializer=szconfig__pb2.DeleteDataSourceResponse.SerializeToString,
            ),
            'ExportConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportConfig,
                    request_deserializer=szconfig__pb2.ExportConfigRequest.FromString,
                    response_serializer=szconfig__pb2.ExportConfigResponse.SerializeToString,
            ),
            'GetDataSources': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSources,
                    request_deserializer=szconfig__pb2.GetDataSourcesRequest.FromString,
                    response_serializer=szconfig__pb2.GetDataSourcesResponse.SerializeToString,
            ),
            'ImportConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportConfig,
                    request_deserializer=szconfig__pb2.ImportConfigRequest.FromString,
                    response_serializer=szconfig__pb2.ImportConfigResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'szconfig.SzConfig', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('szconfig.SzConfig', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SzConfig(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfig.SzConfig/AddDataSource',
            szconfig__pb2.AddDataSourceRequest.SerializeToString,
            szconfig__pb2.AddDataSourceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CloseConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfig.SzConfig/CloseConfig',
            szconfig__pb2.CloseConfigRequest.SerializeToString,
            szconfig__pb2.CloseConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfig.SzConfig/CreateConfig',
            szconfig__pb2.CreateConfigRequest.SerializeToString,
            szconfig__pb2.CreateConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfig.SzConfig/DeleteDataSource',
            szconfig__pb2.DeleteDataSourceRequest.SerializeToString,
            szconfig__pb2.DeleteDataSourceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfig.SzConfig/ExportConfig',
            szconfig__pb2.ExportConfigRequest.SerializeToString,
            szconfig__pb2.ExportConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDataSources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfig.SzConfig/GetDataSources',
            szconfig__pb2.GetDataSourcesRequest.SerializeToString,
            szconfig__pb2.GetDataSourcesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ImportConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szconfig.SzConfig/ImportConfig',
            szconfig__pb2.ImportConfigRequest.SerializeToString,
            szconfig__pb2.ImportConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



#! /usr/bin/env python3

"""
TODO: szconfig_grpc.py
"""

# pylint: disable=E1101

from types import TracebackType
from typing import Any, Dict, Type, Union

import grpc
from senzing_abstract import SzConfigAbstract

from .pb2_grpc import szconfig_pb2, szconfig_pb2_grpc

# from .szabstract.szconfig_abstract import SzConfigAbstract
from .szhelpers import as_str, new_exception

# Metadata

__all__ = ["SzConfig"]
__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2023-11-27"
__updated__ = "2024-07-30"

SENZING_PRODUCT_ID = (
    "5050"  # See https://github.com/senzing-garage/knowledge-base/blob/main/lists/senzing-component-ids.md
)

# -----------------------------------------------------------------------------
# SzConfig class
# -----------------------------------------------------------------------------


class SzConfig(SzConfigAbstract):
    """
    SzConfig module access library over gRPC.
    """

    # -------------------------------------------------------------------------
    # Python dunder/magic methods
    # -------------------------------------------------------------------------

    def __init__(
        self,
        grpc_channel: grpc.Channel,
    ) -> None:
        """
        Constructor

        For return value of -> None, see https://peps.python.org/pep-0484/#the-meaning-of-annotations
        """

        self.channel = grpc_channel
        self.stub = szconfig_pb2_grpc.SzConfigStub(self.channel)

    def __enter__(
        self,
    ) -> Any:  # TODO: Replace "Any" with "Self" once python 3.11 is lowest supported python version.
        """Context Manager method."""
        return self

    def __exit__(
        self,
        exc_type: Union[Type[BaseException], None],
        exc_val: Union[BaseException, None],
        exc_tb: Union[TracebackType, None],
    ) -> None:
        """Context Manager method."""

    # -------------------------------------------------------------------------
    # SzConfig methods
    # -------------------------------------------------------------------------

    def add_data_source(
        self,
        config_handle: int,
        data_source_code: str,
    ) -> str:
        try:
            request = szconfig_pb2.AddDataSourceRequest(  # type: ignore[unused-ignore]
                configHandle=config_handle, dataSourceCode=as_str(data_source_code)
            )
            response = self.stub.AddDataSource(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def close_config(self, config_handle: int) -> None:
        try:
            request = szconfig_pb2.CloseConfigRequest(configHandle=config_handle)  # type: ignore[unused-ignore]
            self.stub.CloseConfig(request)
        except Exception as err:
            raise new_exception(err) from err

    def create_config(self) -> int:
        try:
            request = szconfig_pb2.CreateConfigRequest()  # type: ignore[unused-ignore]
            response = self.stub.CreateConfig(request)
            return int(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def delete_data_source(self, config_handle: int, data_source_code: str) -> None:
        try:
            request = szconfig_pb2.DeleteDataSourceRequest(configHandle=config_handle, dataSourceCode=as_str(data_source_code))  # type: ignore[unused-ignore]
            self.stub.DeleteDataSource(request)
        except Exception as err:
            raise new_exception(err) from err

    def _destroy(self) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""

    def export_config(self, config_handle: int) -> str:
        try:
            request = szconfig_pb2.ExportConfigRequest(configHandle=config_handle)  # type: ignore[unused-ignore]
            response = self.stub.ExportConfig(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def get_data_sources(self, config_handle: int) -> str:
        try:
            request = szconfig_pb2.GetDataSourcesRequest(configHandle=config_handle)  # type: ignore[unused-ignore]
            response = self.stub.GetDataSources(request)
            return str(response.result)
        except Exception as err:
            raise new_exception(err) from err

    def _initialize(
        self,
        instance_name: str,
        settings: Union[str, Dict[Any, Any]],
        verbose_logging: int = 0,
    ) -> None:
        """Null function in the sz-sdk-python-grpc implementation."""
        _ = instance_name
        _ = settings
        _ = verbose_logging

    def import_config(self, config_definition: str) -> int:
        try:
            request = szconfig_pb2.ImportConfigRequest(configDefinition=as_str(config_definition))  # type: ignore[unused-ignore]
            response = self.stub.ImportConfig(request)
            return int(response.result)
        except Exception as err:
            raise new_exception(err) from err



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: szdiagnostic.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12szdiagnostic.proto\x12\x0cszdiagnostic\"8\n CheckDatastorePerformanceRequest\x12\x14\n\x0csecondsToRun\x18\x01 \x01(\x05\"3\n!CheckDatastorePerformanceResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x19\n\x17GetDatastoreInfoRequest\"*\n\x18GetDatastoreInfoResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"&\n\x11GetFeatureRequest\x12\x11\n\tfeatureId\x18\x01 \x01(\x03\"$\n\x12GetFeatureResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x18\n\x16PurgeRepositoryRequest\"\x19\n\x17PurgeRepositoryResponse\"\'\n\x13ReinitializeRequest\x12\x10\n\x08\x63onfigId\x18\x01 \x01(\x03\"\x16\n\x14ReinitializeResponse2\x81\x04\n\x0cSzDiagnostic\x12~\n\x19\x43heckDatastorePerformance\x12..szdiagnostic.CheckDatastorePerformanceRequest\x1a/.szdiagnostic.CheckDatastorePerformanceResponse\"\x00\x12\x63\n\x10GetDatastoreInfo\x12%.szdiagnostic.GetDatastoreInfoRequest\x1a&.szdiagnostic.GetDatastoreInfoResponse\"\x00\x12Q\n\nGetFeature\x12\x1f.szdiagnostic.GetFeatureRequest\x1a .szdiagnostic.GetFeatureResponse\"\x00\x12`\n\x0fPurgeRepository\x12$.szdiagnostic.PurgeRepositoryRequest\x1a%.szdiagnostic.PurgeRepositoryResponse\"\x00\x12W\n\x0cReinitialize\x12!.szdiagnostic.ReinitializeRequest\x1a\".szdiagnostic.ReinitializeResponse\"\x00\x42s\n\'com.senzing.sz.engine.grpc.SzDiagnosticB\x11SzDiagnosticProtoZ5github.com/senzing-garage/sz-sdk-go-grpc/szdiagnosticb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szdiagnostic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.senzing.sz.engine.grpc.SzDiagnosticB\021SzDiagnosticProtoZ5github.com/senzing-garage/sz-sdk-go-grpc/szdiagnostic'
  _globals['_CHECKDATASTOREPERFORMANCEREQUEST']._serialized_start=36
  _globals['_CHECKDATASTOREPERFORMANCEREQUEST']._serialized_end=92
  _globals['_CHECKDATASTOREPERFORMANCERESPONSE']._serialized_start=94
  _globals['_CHECKDATASTOREPERFORMANCERESPONSE']._serialized_end=145
  _globals['_GETDATASTOREINFOREQUEST']._serialized_start=147
  _globals['_GETDATASTOREINFOREQUEST']._serialized_end=172
  _globals['_GETDATASTOREINFORESPONSE']._serialized_start=174
  _globals['_GETDATASTOREINFORESPONSE']._serialized_end=216
  _globals['_GETFEATUREREQUEST']._serialized_start=218
  _globals['_GETFEATUREREQUEST']._serialized_end=256
  _globals['_GETFEATURERESPONSE']._serialized_start=258
  _globals['_GETFEATURERESPONSE']._serialized_end=294
  _globals['_PURGEREPOSITORYREQUEST']._serialized_start=296
  _globals['_PURGEREPOSITORYREQUEST']._serialized_end=320
  _globals['_PURGEREPOSITORYRESPONSE']._serialized_start=322
  _globals['_PURGEREPOSITORYRESPONSE']._serialized_end=347
  _globals['_REINITIALIZEREQUEST']._serialized_start=349
  _globals['_REINITIALIZEREQUEST']._serialized_end=388
  _globals['_REINITIALIZERESPONSE']._serialized_start=390
  _globals['_REINITIALIZERESPONSE']._serialized_end=412
  _globals['_SZDIAGNOSTIC']._serialized_start=415
  _globals['_SZDIAGNOSTIC']._serialized_end=928
# @@protoc_insertion_point(module_scope)



from senzing_abstract import (
    ENGINE_EXCEPTION_MAP,
    SZ_INITIALIZE_WITH_DEFAULT_CONFIGURATION,
    SZ_NO_ATTRIBUTES,
    SZ_NO_AVOIDANCES,
    SZ_NO_FLAGS,
    SZ_NO_LOGGING,
    SZ_NO_REQUIRED_DATASOURCES,
    SZ_NO_SEARCH_PROFILE,
    SZ_VERBOSE_LOGGING,
    SZ_WITHOUT_INFO,
    SzBadInputError,
)
from senzing_abstract import SzConfigAbstract as SzConfig
from senzing_abstract import SzConfigManagerAbstract as SzConfigManager
from senzing_abstract import (
    SzConfigurationError,
    SzDatabaseConnectionLostError,
    SzDatabaseError,
)
from senzing_abstract import SzDiagnosticAbstract as SzDiagnostic
from senzing_abstract import SzEngineAbstract as SzEngine
from senzing_abstract import (
    SzEngineFlags,
    SzError,
    SzLicenseError,
    SzNotFoundError,
    SzNotInitializedError,
)
from senzing_abstract import SzProductAbstract as SzProduct
from senzing_abstract import (
    SzReplaceConflictError,
    SzRetryableError,
    SzRetryTimeoutExceededError,
    SzUnhandledError,
    SzUnknownDataSourceError,
    SzUnrecoverableError,
)

from .szabstractfactory import SzAbstractFactory, SzAbstractFactoryParameters
from .szconfig import SzConfig as SzConfigGrpc
from .szconfigmanager import SzConfigManager as SzConfigManagerGrpc
from .szdiagnostic import SzDiagnostic as SzDiagnosticGrpc
from .szengine import SzEngine as SzEngineGrpc
from .szproduct import SzProduct as SzProductGrpc

__all__ = [
    "ENGINE_EXCEPTION_MAP",
    "SZ_INITIALIZE_WITH_DEFAULT_CONFIGURATION",
    "SZ_NO_ATTRIBUTES",
    "SZ_NO_AVOIDANCES",
    "SZ_NO_FLAGS",
    "SZ_NO_LOGGING",
    "SZ_NO_LOGGING",
    "SZ_NO_REQUIRED_DATASOURCES",
    "SZ_NO_SEARCH_PROFILE",
    "SZ_VERBOSE_LOGGING",
    "SZ_WITHOUT_INFO",
    "SzAbstractFactory",
    "SzAbstractFactoryParameters",
    "SzBadInputError",
    "SzConfig",
    "SzConfigGrpc",
    "SzConfigManager",
    "SzConfigManagerGrpc",
    "SzConfigurationError",
    "SzDatabaseConnectionLostError",
    "SzDatabaseError",
    "SzDiagnostic",
    "SzDiagnosticGrpc",
    "SzEngine",
    "SzEngineGrpc",
    "SzEngineFlags",
    "SzError",
    "SzLicenseError",
    "SzNotFoundError",
    "SzNotInitializedError",
    "SzProduct",
    "SzProductGrpc",
    "SzReplaceConflictError",
    "SzRetryableError",
    "SzRetryTimeoutExceededError",
    "SzUnhandledError",
    "SzUnknownDataSourceError",
    "SzUnrecoverableError",
]



"""
TODO: szhelpers.py
"""

import json
from typing import Any, Dict, Union

import grpc
import grpc._channel
from senzing_abstract import ENGINE_EXCEPTION_MAP, SzError

# Metadata

__version__ = "0.0.1"  # See https://www.python.org/dev/peps/pep-0396/
__date__ = "2023-11-27"
__updated__ = "2023-12-16"

# -----------------------------------------------------------------------------
# Helpers for working with parameters
# -----------------------------------------------------------------------------


def as_str(candidate_value: Union[str, Dict[Any, Any]]) -> str:
    """
    Given a string or dict, return a str.

    Args:
        candidate_value (Union[str, Dict[Any, Any]]): _description_

    Returns:
        str: The string representation of the candidate_value
    """
    if isinstance(candidate_value, dict):
        return json.dumps(candidate_value)
    return candidate_value


# -----------------------------------------------------------------------------
# Helpers for working with errors
# -----------------------------------------------------------------------------


def get_senzing_error_code(error_text: str) -> int:
    """
    Given an exception string, find the exception code.

    :meta private:
    """
    if len(error_text) == 0:
        return 0
    exception_message_splits = error_text.split("|", 1)
    try:
        result = int(exception_message_splits[0].strip().lstrip("SENZ"))
    except ValueError:
        print(f"ERROR: Could not parse error text '{error_text}'")
        result = 9999
    return result


def new_exception(initial_exception: Exception) -> Exception:
    """
    Given an exception, determine which Senzing exception is is.

    Args:
        initial_exception (Exception): An unknown Exception

    Returns:
        Exception: Either a SzError or the original exception.
    """

    result = initial_exception
    if isinstance(initial_exception, grpc.RpcError):
        details = initial_exception.details()  # type: ignore[unused-ignore]
        details_dict = {}
        try:
            details_dict = json.loads(details)
        except Exception:  # pylint: disable=W0718
            details_dict = {}
        errors_reason = details_dict.get("reason", "")
        senzing_error_code = get_senzing_error_code(errors_reason)
        senzing_error_class = ENGINE_EXCEPTION_MAP.get(senzing_error_code, SzError)
        result = senzing_error_class(details)
    return result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: szengine.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eszengine.proto\x12\x08szengine\"e\n\x10\x41\x64\x64RecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordId\x18\x02 \x01(\t\x12\x18\n\x10recordDefinition\x18\x03 \x01(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\x03\"#\n\x11\x41\x64\x64RecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"*\n\x12\x43loseExportRequest\x12\x14\n\x0c\x65xportHandle\x18\x01 \x01(\x03\"\x15\n\x13\x43loseExportResponse\"\x19\n\x17\x43ountRedoRecordsRequest\"*\n\x18\x43ountRedoRecordsResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"N\n\x13\x44\x65leteRecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordId\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"&\n\x14\x44\x65leteRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"D\n\x1c\x45xportCsvEntityReportRequest\x12\x15\n\rcsvColumnList\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"/\n\x1d\x45xportCsvEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\".\n\x1d\x45xportJsonEntityReportRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\x03\"0\n\x1e\x45xportJsonEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"(\n\x10\x46\x65tchNextRequest\x12\x14\n\x0c\x65xportHandle\x18\x01 \x01(\x03\"#\n\x11\x46\x65tchNextResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"K\n(FindInterestingEntitiesByEntityIdRequest\x12\x10\n\x08\x65ntityId\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\";\n)FindInterestingEntitiesByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"c\n(FindInterestingEntitiesByRecordIdRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordId\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\";\n)FindInterestingEntitiesByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x8a\x01\n\x1c\x46indNetworkByEntityIdRequest\x12\x11\n\tentityIds\x18\x01 \x01(\t\x12\x12\n\nmaxDegrees\x18\x02 \x01(\x03\x12\x17\n\x0f\x62uildOutDegrees\x18\x03 \x01(\x03\x12\x1b\n\x13\x62uildOutMaxEntities\x18\x04 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"/\n\x1d\x46indNetworkByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x8b\x01\n\x1c\x46indNetworkByRecordIdRequest\x12\x12\n\nrecordKeys\x18\x01 \x01(\t\x12\x12\n\nmaxDegrees\x18\x02 \x01(\x03\x12\x17\n\x0f\x62uildOutDegrees\x18\x03 \x01(\x03\x12\x1b\n\x13\x62uildOutMaxEntities\x18\x04 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"/\n\x1d\x46indNetworkByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x9f\x01\n\x19\x46indPathByEntityIdRequest\x12\x15\n\rstartEntityId\x18\x01 \x01(\x03\x12\x13\n\x0b\x65ndEntityId\x18\x02 \x01(\x03\x12\x12\n\nmaxDegrees\x18\x03 \x01(\x03\x12\x16\n\x0e\x61voidEntityIds\x18\x04 \x01(\t\x12\x1b\n\x13requiredDataSources\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\x03\",\n\x1a\x46indPathByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\xd8\x01\n\x19\x46indPathByRecordIdRequest\x12\x1b\n\x13startDataSourceCode\x18\x01 \x01(\t\x12\x15\n\rstartRecordId\x18\x02 \x01(\t\x12\x19\n\x11\x65ndDataSourceCode\x18\x03 \x01(\t\x12\x13\n\x0b\x65ndRecordId\x18\x04 \x01(\t\x12\x12\n\nmaxDegrees\x18\x05 \x01(\x03\x12\x17\n\x0f\x61voidRecordKeys\x18\x06 \x01(\t\x12\x1b\n\x13requiredDataSources\x18\x07 \x01(\t\x12\r\n\x05\x66lags\x18\x08 \x01(\x03\",\n\x1a\x46indPathByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x1a\n\x18GetActiveConfigIdRequest\"+\n\x19GetActiveConfigIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"=\n\x1aGetEntityByEntityIdRequest\x12\x10\n\x08\x65ntityId\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"-\n\x1bGetEntityByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"U\n\x1aGetEntityByRecordIdRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordId\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"-\n\x1bGetEntityByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"K\n\x10GetRecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordId\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"#\n\x11GetRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x16\n\x14GetRedoRecordRequest\"\'\n\x15GetRedoRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x11\n\x0fGetStatsRequest\"\"\n\x10GetStatsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"F\n!GetVirtualEntityByRecordIdRequest\x12\x12\n\nrecordKeys\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"4\n\"GetVirtualEntityByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"=\n\x1aHowEntityByEntityIdRequest\x12\x10\n\x08\x65ntityId\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"-\n\x1bHowEntityByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"B\n\x17PreprocessRecordRequest\x12\x18\n\x10recordDefinition\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"*\n\x18PreprocessRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x14\n\x12PrimeEngineRequest\"\x15\n\x13PrimeEngineResponse\"=\n\x18ProcessRedoRecordRequest\x12\x12\n\nredoRecord\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"+\n\x19ProcessRedoRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\":\n\x17ReevaluateEntityRequest\x12\x10\n\x08\x65ntityId\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"*\n\x18ReevaluateEntityResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"R\n\x17ReevaluateRecordRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordId\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"*\n\x18ReevaluateRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\'\n\x13ReinitializeRequest\x12\x10\n\x08\x63onfigId\x18\x01 \x01(\x03\"\x16\n\x14ReinitializeResponse\"U\n\x19SearchByAttributesRequest\x12\x12\n\nattributes\x18\x01 \x01(\t\x12\x15\n\rsearchProfile\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\",\n\x1aSearchByAttributesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"J\n\"StreamExportCsvEntityReportRequest\x12\x15\n\rcsvColumnList\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"5\n#StreamExportCsvEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"4\n#StreamExportJsonEntityReportRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\x03\"6\n$StreamExportJsonEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"I\n\x12WhyEntitiesRequest\x12\x11\n\tentityId1\x18\x01 \x01(\x03\x12\x11\n\tentityId2\x18\x02 \x01(\x03\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"%\n\x13WhyEntitiesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"S\n\x18WhyRecordInEntityRequest\x12\x16\n\x0e\x64\x61taSourceCode\x18\x01 \x01(\t\x12\x10\n\x08recordId\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"+\n\x19WhyRecordInEntityResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"z\n\x11WhyRecordsRequest\x12\x17\n\x0f\x64\x61taSourceCode1\x18\x01 \x01(\t\x12\x11\n\trecordId1\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x61taSourceCode2\x18\x03 \x01(\t\x12\x11\n\trecordId2\x18\x04 \x01(\t\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"$\n\x12WhyRecordsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t2\x95\x19\n\x08SzEngine\x12\x46\n\tAddRecord\x12\x1a.szengine.AddRecordRequest\x1a\x1b.szengine.AddRecordResponse\"\x00\x12L\n\x0b\x43loseExport\x12\x1c.szengine.CloseExportRequest\x1a\x1d.szengine.CloseExportResponse\"\x00\x12[\n\x10\x43ountRedoRecords\x12!.szengine.CountRedoRecordsRequest\x1a\".szengine.CountRedoRecordsResponse\"\x00\x12O\n\x0c\x44\x65leteRecord\x12\x1d.szengine.DeleteRecordRequest\x1a\x1e.szengine.DeleteRecordResponse\"\x00\x12j\n\x15\x45xportCsvEntityReport\x12&.szengine.ExportCsvEntityReportRequest\x1a\'.szengine.ExportCsvEntityReportResponse\"\x00\x12m\n\x16\x45xportJsonEntityReport\x12\'.szengine.ExportJsonEntityReportRequest\x1a(.szengine.ExportJsonEntityReportResponse\"\x00\x12\x46\n\tFetchNext\x12\x1a.szengine.FetchNextRequest\x1a\x1b.szengine.FetchNextResponse\"\x00\x12\x8e\x01\n!FindInterestingEntitiesByEntityId\x12\x32.szengine.FindInterestingEntitiesByEntityIdRequest\x1a\x33.szengine.FindInterestingEntitiesByEntityIdResponse\"\x00\x12\x8e\x01\n!FindInterestingEntitiesByRecordId\x12\x32.szengine.FindInterestingEntitiesByRecordIdRequest\x1a\x33.szengine.FindInterestingEntitiesByRecordIdResponse\"\x00\x12j\n\x15\x46indNetworkByEntityId\x12&.szengine.FindNetworkByEntityIdRequest\x1a\'.szengine.FindNetworkByEntityIdResponse\"\x00\x12j\n\x15\x46indNetworkByRecordId\x12&.szengine.FindNetworkByRecordIdRequest\x1a\'.szengine.FindNetworkByRecordIdResponse\"\x00\x12\x61\n\x12\x46indPathByEntityId\x12#.szengine.FindPathByEntityIdRequest\x1a$.szengine.FindPathByEntityIdResponse\"\x00\x12\x61\n\x12\x46indPathByRecordId\x12#.szengine.FindPathByRecordIdRequest\x1a$.szengine.FindPathByRecordIdResponse\"\x00\x12^\n\x11GetActiveConfigId\x12\".szengine.GetActiveConfigIdRequest\x1a#.szengine.GetActiveConfigIdResponse\"\x00\x12\x64\n\x13GetEntityByEntityId\x12$.szengine.GetEntityByEntityIdRequest\x1a%.szengine.GetEntityByEntityIdResponse\"\x00\x12\x64\n\x13GetEntityByRecordId\x12$.szengine.GetEntityByRecordIdRequest\x1a%.szengine.GetEntityByRecordIdResponse\"\x00\x12\x46\n\tGetRecord\x12\x1a.szengine.GetRecordRequest\x1a\x1b.szengine.GetRecordResponse\"\x00\x12R\n\rGetRedoRecord\x12\x1e.szengine.GetRedoRecordRequest\x1a\x1f.szengine.GetRedoRecordResponse\"\x00\x12\x43\n\x08GetStats\x12\x19.szengine.GetStatsRequest\x1a\x1a.szengine.GetStatsResponse\"\x00\x12y\n\x1aGetVirtualEntityByRecordId\x12+.szengine.GetVirtualEntityByRecordIdRequest\x1a,.szengine.GetVirtualEntityByRecordIdResponse\"\x00\x12\x64\n\x13HowEntityByEntityId\x12$.szengine.HowEntityByEntityIdRequest\x1a%.szengine.HowEntityByEntityIdResponse\"\x00\x12[\n\x10PreprocessRecord\x12!.szengine.PreprocessRecordRequest\x1a\".szengine.PreprocessRecordResponse\"\x00\x12L\n\x0bPrimeEngine\x12\x1c.szengine.PrimeEngineRequest\x1a\x1d.szengine.PrimeEngineResponse\"\x00\x12^\n\x11ProcessRedoRecord\x12\".szengine.ProcessRedoRecordRequest\x1a#.szengine.ProcessRedoRecordResponse\"\x00\x12[\n\x10ReevaluateEntity\x12!.szengine.ReevaluateEntityRequest\x1a\".szengine.ReevaluateEntityResponse\"\x00\x12[\n\x10ReevaluateRecord\x12!.szengine.ReevaluateRecordRequest\x1a\".szengine.ReevaluateRecordResponse\"\x00\x12O\n\x0cReinitialize\x12\x1d.szengine.ReinitializeRequest\x1a\x1e.szengine.ReinitializeResponse\"\x00\x12\x61\n\x12SearchByAttributes\x12#.szengine.SearchByAttributesRequest\x1a$.szengine.SearchByAttributesResponse\"\x00\x12~\n\x1bStreamExportCsvEntityReport\x12,.szengine.StreamExportCsvEntityReportRequest\x1a-.szengine.StreamExportCsvEntityReportResponse\"\x00\x30\x01\x12\x81\x01\n\x1cStreamExportJsonEntityReport\x12-.szengine.StreamExportJsonEntityReportRequest\x1a..szengine.StreamExportJsonEntityReportResponse\"\x00\x30\x01\x12L\n\x0bWhyEntities\x12\x1c.szengine.WhyEntitiesRequest\x1a\x1d.szengine.WhyEntitiesResponse\"\x00\x12^\n\x11WhyRecordInEntity\x12\".szengine.WhyRecordInEntityRequest\x1a#.szengine.WhyRecordInEntityResponse\"\x00\x12I\n\nWhyRecords\x12\x1b.szengine.WhyRecordsRequest\x1a\x1c.szengine.WhyRecordsResponse\"\x00\x42g\n#com.senzing.sz.engine.grpc.SzEngineB\rSzEngineProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szengineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szengine_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.senzing.sz.engine.grpc.SzEngineB\rSzEngineProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szengine'
  _globals['_ADDRECORDREQUEST']._serialized_start=28
  _globals['_ADDRECORDREQUEST']._serialized_end=129
  _globals['_ADDRECORDRESPONSE']._serialized_start=131
  _globals['_ADDRECORDRESPONSE']._serialized_end=166
  _globals['_CLOSEEXPORTREQUEST']._serialized_start=168
  _globals['_CLOSEEXPORTREQUEST']._serialized_end=210
  _globals['_CLOSEEXPORTRESPONSE']._serialized_start=212
  _globals['_CLOSEEXPORTRESPONSE']._serialized_end=233
  _globals['_COUNTREDORECORDSREQUEST']._serialized_start=235
  _globals['_COUNTREDORECORDSREQUEST']._serialized_end=260
  _globals['_COUNTREDORECORDSRESPONSE']._serialized_start=262
  _globals['_COUNTREDORECORDSRESPONSE']._serialized_end=304
  _globals['_DELETERECORDREQUEST']._serialized_start=306
  _globals['_DELETERECORDREQUEST']._serialized_end=384
  _globals['_DELETERECORDRESPONSE']._serialized_start=386
  _globals['_DELETERECORDRESPONSE']._serialized_end=424
  _globals['_EXPORTCSVENTITYREPORTREQUEST']._serialized_start=426
  _globals['_EXPORTCSVENTITYREPORTREQUEST']._serialized_end=494
  _globals['_EXPORTCSVENTITYREPORTRESPONSE']._serialized_start=496
  _globals['_EXPORTCSVENTITYREPORTRESPONSE']._serialized_end=543
  _globals['_EXPORTJSONENTITYREPORTREQUEST']._serialized_start=545
  _globals['_EXPORTJSONENTITYREPORTREQUEST']._serialized_end=591
  _globals['_EXPORTJSONENTITYREPORTRESPONSE']._serialized_start=593
  _globals['_EXPORTJSONENTITYREPORTRESPONSE']._serialized_end=641
  _globals['_FETCHNEXTREQUEST']._serialized_start=643
  _globals['_FETCHNEXTREQUEST']._serialized_end=683
  _globals['_FETCHNEXTRESPONSE']._serialized_start=685
  _globals['_FETCHNEXTRESPONSE']._serialized_end=720
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDREQUEST']._serialized_start=722
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDREQUEST']._serialized_end=797
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDRESPONSE']._serialized_start=799
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDRESPONSE']._serialized_end=858
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDREQUEST']._serialized_start=860
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDREQUEST']._serialized_end=959
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDRESPONSE']._serialized_start=961
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDRESPONSE']._serialized_end=1020
  _globals['_FINDNETWORKBYENTITYIDREQUEST']._serialized_start=1023
  _globals['_FINDNETWORKBYENTITYIDREQUEST']._serialized_end=1161
  _globals['_FINDNETWORKBYENTITYIDRESPONSE']._serialized_start=1163
  _globals['_FINDNETWORKBYENTITYIDRESPONSE']._serialized_end=1210
  _globals['_FINDNETWORKBYRECORDIDREQUEST']._serialized_start=1213
  _globals['_FINDNETWORKBYRECORDIDREQUEST']._serialized_end=1352
  _globals['_FINDNETWORKBYRECORDIDRESPONSE']._serialized_start=1354
  _globals['_FINDNETWORKBYRECORDIDRESPONSE']._serialized_end=1401
  _globals['_FINDPATHBYENTITYIDREQUEST']._serialized_start=1404
  _globals['_FINDPATHBYENTITYIDREQUEST']._serialized_end=1563
  _globals['_FINDPATHBYENTITYIDRESPONSE']._serialized_start=1565
  _globals['_FINDPATHBYENTITYIDRESPONSE']._serialized_end=1609
  _globals['_FINDPATHBYRECORDIDREQUEST']._serialized_start=1612
  _globals['_FINDPATHBYRECORDIDREQUEST']._serialized_end=1828
  _globals['_FINDPATHBYRECORDIDRESPONSE']._serialized_start=1830
  _globals['_FINDPATHBYRECORDIDRESPONSE']._serialized_end=1874
  _globals['_GETACTIVECONFIGIDREQUEST']._serialized_start=1876
  _globals['_GETACTIVECONFIGIDREQUEST']._serialized_end=1902
  _globals['_GETACTIVECONFIGIDRESPONSE']._serialized_start=1904
  _globals['_GETACTIVECONFIGIDRESPONSE']._serialized_end=1947
  _globals['_GETENTITYBYENTITYIDREQUEST']._serialized_start=1949
  _globals['_GETENTITYBYENTITYIDREQUEST']._serialized_end=2010
  _globals['_GETENTITYBYENTITYIDRESPONSE']._serialized_start=2012
  _globals['_GETENTITYBYENTITYIDRESPONSE']._serialized_end=2057
  _globals['_GETENTITYBYRECORDIDREQUEST']._serialized_start=2059
  _globals['_GETENTITYBYRECORDIDREQUEST']._serialized_end=2144
  _globals['_GETENTITYBYRECORDIDRESPONSE']._serialized_start=2146
  _globals['_GETENTITYBYRECORDIDRESPONSE']._serialized_end=2191
  _globals['_GETRECORDREQUEST']._serialized_start=2193
  _globals['_GETRECORDREQUEST']._serialized_end=2268
  _globals['_GETRECORDRESPONSE']._serialized_start=2270
  _globals['_GETRECORDRESPONSE']._serialized_end=2305
  _globals['_GETREDORECORDREQUEST']._serialized_start=2307
  _globals['_GETREDORECORDREQUEST']._serialized_end=2329
  _globals['_GETREDORECORDRESPONSE']._serialized_start=2331
  _globals['_GETREDORECORDRESPONSE']._serialized_end=2370
  _globals['_GETSTATSREQUEST']._serialized_start=2372
  _globals['_GETSTATSREQUEST']._serialized_end=2389
  _globals['_GETSTATSRESPONSE']._serialized_start=2391
  _globals['_GETSTATSRESPONSE']._serialized_end=2425
  _globals['_GETVIRTUALENTITYBYRECORDIDREQUEST']._serialized_start=2427
  _globals['_GETVIRTUALENTITYBYRECORDIDREQUEST']._serialized_end=2497
  _globals['_GETVIRTUALENTITYBYRECORDIDRESPONSE']._serialized_start=2499
  _globals['_GETVIRTUALENTITYBYRECORDIDRESPONSE']._serialized_end=2551
  _globals['_HOWENTITYBYENTITYIDREQUEST']._serialized_start=2553
  _globals['_HOWENTITYBYENTITYIDREQUEST']._serialized_end=2614
  _globals['_HOWENTITYBYENTITYIDRESPONSE']._serialized_start=2616
  _globals['_HOWENTITYBYENTITYIDRESPONSE']._serialized_end=2661
  _globals['_PREPROCESSRECORDREQUEST']._serialized_start=2663
  _globals['_PREPROCESSRECORDREQUEST']._serialized_end=2729
  _globals['_PREPROCESSRECORDRESPONSE']._serialized_start=2731
  _globals['_PREPROCESSRECORDRESPONSE']._serialized_end=2773
  _globals['_PRIMEENGINEREQUEST']._serialized_start=2775
  _globals['_PRIMEENGINEREQUEST']._serialized_end=2795
  _globals['_PRIMEENGINERESPONSE']._serialized_start=2797
  _globals['_PRIMEENGINERESPONSE']._serialized_end=2818
  _globals['_PROCESSREDORECORDREQUEST']._serialized_start=2820
  _globals['_PROCESSREDORECORDREQUEST']._serialized_end=2881
  _globals['_PROCESSREDORECORDRESPONSE']._serialized_start=2883
  _globals['_PROCESSREDORECORDRESPONSE']._serialized_end=2926
  _globals['_REEVALUATEENTITYREQUEST']._serialized_start=2928
  _globals['_REEVALUATEENTITYREQUEST']._serialized_end=2986
  _globals['_REEVALUATEENTITYRESPONSE']._serialized_start=2988
  _globals['_REEVALUATEENTITYRESPONSE']._serialized_end=3030
  _globals['_REEVALUATERECORDREQUEST']._serialized_start=3032
  _globals['_REEVALUATERECORDREQUEST']._serialized_end=3114
  _globals['_REEVALUATERECORDRESPONSE']._serialized_start=3116
  _globals['_REEVALUATERECORDRESPONSE']._serialized_end=3158
  _globals['_REINITIALIZEREQUEST']._serialized_start=3160
  _globals['_REINITIALIZEREQUEST']._serialized_end=3199
  _globals['_REINITIALIZERESPONSE']._serialized_start=3201
  _globals['_REINITIALIZERESPONSE']._serialized_end=3223
  _globals['_SEARCHBYATTRIBUTESREQUEST']._serialized_start=3225
  _globals['_SEARCHBYATTRIBUTESREQUEST']._serialized_end=3310
  _globals['_SEARCHBYATTRIBUTESRESPONSE']._serialized_start=3312
  _globals['_SEARCHBYATTRIBUTESRESPONSE']._serialized_end=3356
  _globals['_STREAMEXPORTCSVENTITYREPORTREQUEST']._serialized_start=3358
  _globals['_STREAMEXPORTCSVENTITYREPORTREQUEST']._serialized_end=3432
  _globals['_STREAMEXPORTCSVENTITYREPORTRESPONSE']._serialized_start=3434
  _globals['_STREAMEXPORTCSVENTITYREPORTRESPONSE']._serialized_end=3487
  _globals['_STREAMEXPORTJSONENTITYREPORTREQUEST']._serialized_start=3489
  _globals['_STREAMEXPORTJSONENTITYREPORTREQUEST']._serialized_end=3541
  _globals['_STREAMEXPORTJSONENTITYREPORTRESPONSE']._serialized_start=3543
  _globals['_STREAMEXPORTJSONENTITYREPORTRESPONSE']._serialized_end=3597
  _globals['_WHYENTITIESREQUEST']._serialized_start=3599
  _globals['_WHYENTITIESREQUEST']._serialized_end=3672
  _globals['_WHYENTITIESRESPONSE']._serialized_start=3674
  _globals['_WHYENTITIESRESPONSE']._serialized_end=3711
  _globals['_WHYRECORDINENTITYREQUEST']._serialized_start=3713
  _globals['_WHYRECORDINENTITYREQUEST']._serialized_end=3796
  _globals['_WHYRECORDINENTITYRESPONSE']._serialized_start=3798
  _globals['_WHYRECORDINENTITYRESPONSE']._serialized_end=3841
  _globals['_WHYRECORDSREQUEST']._serialized_start=3843
  _globals['_WHYRECORDSREQUEST']._serialized_end=3965
  _globals['_WHYRECORDSRESPONSE']._serialized_start=3967
  _globals['_WHYRECORDSRESPONSE']._serialized_end=4003
  _globals['_SZENGINE']._serialized_start=4006
  _globals['_SZENGINE']._serialized_end=7227
# @@protoc_insertion_point(module_scope)
